export interface DynamicColumnDataType {
    /**
     * 编码
     */
    code: number;
    /**
     * 名称
     */
    name: string;
    /**
     * 数据库类型
     */
    dbTypeName: string;
}
/**
 * 枚举类型的通用结构
 */
export interface BaseEnumType {
    /**
     * 枚举的代码值
     */
    code: number;
    /**
     * 枚举的名称描述
     */
    name: string;
    /**
     * 枚举的排序值（可选）
     */
    ordinal?: number;
}
export declare const DYNAMIC_COLUMN_DATA_TYPE_TEXT: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_TEXTAREA: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_INT: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_MONEY: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_NUMBER: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_ID_CARD: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_MOBILE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_EMAIL: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_DATE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_DATETIME: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_LABEL: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_SWITCH: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_RADIO: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_CHECKBOX: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_USER: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_DEPT: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_ORGAN: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_SELECT: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_CASCADE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_PICTURE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_VIDEO: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_AUDIO: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_DOC: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_ATTACHMENTS: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_AUTO: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_EDITOR: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_POSITIONING: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_SIGNATURE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_GRADE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_BUTTON: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_CHILDREN_TABLE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_QUOTE: DynamicColumnDataType;
export declare const DYNAMIC_COLUMN_DATA_TYPE_LINKAGE: DynamicColumnDataType;
/**
 * 列类型接口
 */
export interface ColumnType {
    /**
     * 列的唯一标识符
     */
    id: string;
    /**
     * 关联的表 ID
     */
    fkTableId: string;
    /**
     * 表名
     */
    tableName: string;
    /**
     * 列名
     */
    columnName: string;
    /**
     * 选择操作类型
     */
    selectActionType: number;
    /**
     * 选择操作类型的枚举
     */
    selectActionTypeEnum: BaseEnumType;
    /**
     * 列键类型
     */
    columnKeyType: number;
    /**
     * 列键类型的枚举
     */
    columnKeyTypeEnum: BaseEnumType;
    /**
     * 列的数据类型
     */
    columnType: string;
    /**
     * 列的大小
     */
    columnSize: number;
    /**
     * 列的小数位数
     */
    columnDecimal: number;
    /**
     * 默认值
     */
    defaultValue: string;
    /**
     * 默认值类型
     */
    defaultValueType: number;
    /**
     * 默认值类型的枚举
     */
    defaultValueTypeEnum: BaseEnumType;
    /**
     * 是否必填（0：否，1：是）
     */
    isRequired: number;
    /**
     * 是否必填的枚举
     */
    isRequiredEnum: BaseEnumType;
    /**
     * 列的注释
     */
    columnComment: string;
    /**
     * 显示添加类型
     */
    showAddType: number;
    /**
     * 显示添加类型的枚举
     */
    showAddTypeEnum: BaseEnumType;
    /**
     * 显示更新类型
     */
    showUpdateType: number;
    /**
     * 显示更新类型的枚举
     */
    showUpdateTypeEnum: BaseEnumType;
    /**
     * 列在列表中的显示类型
     */
    showListType: number;
    /**
     * 列在列表中的显示类型的枚举
     */
    showListTypeEnum: BaseEnumType;
    /**
     * 列在视图中的显示类型
     */
    showViewType: number;
    /**
     * 列在视图中的显示类型的枚举
     */
    showViewTypeEnum: BaseEnumType;
    /**
     * 搜索类型
     */
    searchType: number;
    /**
     * 搜索类型的枚举
     */
    searchTypeEnum: BaseEnumType;
    /**
     * 更新类型
     */
    updateType: number;
    /**
     * 更新类型的枚举
     */
    updateTypeEnum: BaseEnumType;
    /**
     * 评分代码
     */
    scoreCode: number;
    /**
     * 字段宽度
     */
    fieldWidth: number;
    /**
     * 字段前缀
     */
    fieldPrefix: string;
    /**
     * 显示条件
     */
    showCondition: string;
    /**
     * 唯一性验证
     */
    validationUnique: number;
    /**
     * 唯一性验证的枚举
     */
    validationUniqueEnum: BaseEnumType;
    /**
     * 显示样式
     */
    showStyle: string;
    /**
     * 自定义函数
     */
    customFunction: string;
    /**
     * 列选项列表
     */
    columnOptionList: any[];
    /**
     * 属性列表
     */
    propList: {
        /**
         * 属性的唯一标识符
         */
        id: string;
        /**
         * 属性名称
         */
        propName: string;
        /**
         * 属性值
         */
        propValue: string;
    }[];
    /**
     * 引导文字
     */
    guideWords: string;
    /**
     * 校验表达式
     */
    fieldValidation: string;
    /**
     * 校验类型
     */
    fieldValidationType: string;
    /**
     * 字段后缀
     */
    fieldSuffix: string;
    /**
     * 关联字段
     */
    joinColumn: string;
    /**
     * 关联表单
     */
    joinTable: string;
    /**
     * 关联表单信息
     */
    joinTableInfo: JoinTableInfo;
    /**
     * 连表字段
     */
    linkageColumn: string;
    /**
     * 连表字段
     */
    linkageTableColumn: string;
    /**
     * 选择操作调用的接口
     */
    selectAction: string;
    /**
     * 下拉框选择的标签
     */
    selectActionLabel: string;
    /**
     * 下拉框显示的标签
     */
    selectActionLabelArr: string[];
    /**
     * 下拉框选择的标签
     */
    selectActionValue: string;
}
export interface JoinTableInfo {
    id: string;
    joinAlias: string;
    joinColumnList: JoinColumnList[];
    joinNum: number;
    joinSerial: number;
    joinTableId: string;
    joinTitle: string;
    joinType: number;
    mainTableId: string;
    relationId: string;
    showColumnList: [];
    showColumns: string;
    showType: number;
    tableComment: string;
    valueColumn: string;
}
export interface JoinColumnList {
    id: string;
    conditionKey: string;
    conditionValue: string;
    fkJoinId: string;
    groupSerial: number;
    relation: string;
    valueType: number;
}
